==> material-ui-shell-1.1.2.tgz: package/es/containers/QuestionDialog/QuestionDialog.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import Button from '@material-ui/core/Button';
import Dialog from '@material-ui/core/Dialog';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogContentText from '@material-ui/core/DialogContentText';
import DialogTitle from '@material-ui/core/DialogTitle';
import React, { useContext } from 'react';
import SimpleValuesContext from 'base-shell/lib/providers/SimpleValues/Context';
import Slide from '@material-ui/core/Slide';
import useMediaQuery from '@material-ui/core/useMediaQuery';
import { useIntl } from 'react-intl';
import { useTheme } from '@material-ui/core/styles';
var Transition = React.forwardRef(function (props, ref) {
  return /*#__PURE__*/React.createElement(Slide, _extends({
    direction: "up"
  }, props, {
    ref: ref
  }));
});

var QuestionDialog = function QuestionDialog(_ref) {
  var _ref$id = _ref.id,
      id = _ref$id === void 0 ? '' : _ref$id,
      _ref$message = _ref.message,
      message = _ref$message === void 0 ? '' : _ref$message,
      _ref$title = _ref.title,
      title = _ref$title === void 0 ? '' : _ref$title,
      _ref$action = _ref.action,
      action = _ref$action === void 0 ? '' : _ref$action,
      _ref$handleAction = _ref.handleAction,
      handleAction = _ref$handleAction === void 0 ? function () {} : _ref$handleAction;
  var intl = useIntl();
  var theme = useTheme();

  var _useContext = useContext(SimpleValuesContext),
      getValue = _useContext.getValue,
      setValue = _useContext.setValue;

  var handleClose = function handleClose() {
    setValue(id, false);
  };

  var fullScreen = useMediaQuery(theme.breakpoints.down('sm'));
  var isDialogOpen = getValue(id);
  return /*#__PURE__*/React.createElement(Dialog, {
    fullScreen: fullScreen,
    open: isDialogOpen,
    onClose: handleClose,
    TransitionComponent: Transition,
    "aria-labelledby": "alert-dialog-title",
    "aria-describedby": "alert-dialog-description"
  }, /*#__PURE__*/React.createElement(DialogTitle, {
    id: "alert-dialog-title"
  }, title), /*#__PURE__*/React.createElement(DialogContent, null, /*#__PURE__*/React.createElement(DialogContentText, {
    id: "alert-dialog-description"
  }, message)), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
    onClick: handleClose,
    color: "primary"
  }, intl.formatMessage({
    id: 'cancel'
  })), /*#__PURE__*/React.createElement(Button, {
    onClick: function onClick() {
      handleAction(handleClose);
    },
    color: "secondary"
  }, action)));
};

export default QuestionDialog;

==> material-ui-shell-1.1.3.tgz: package/es/containers/QuestionDialog/QuestionDialog.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import Button from '@material-ui/core/Button';
import Dialog from '@material-ui/core/Dialog';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogContentText from '@material-ui/core/DialogContentText';
import DialogTitle from '@material-ui/core/DialogTitle';
import React, { useContext } from 'react';
import Slide from '@material-ui/core/Slide';
import useMediaQuery from '@material-ui/core/useMediaQuery';
import { useIntl } from 'react-intl';
import { useSimpleValues } from 'base-shell/lib/providers/SimpleValues';
import { useTheme } from '@material-ui/core/styles';
var Transition = React.forwardRef(function (props, ref) {
  return /*#__PURE__*/React.createElement(Slide, _extends({
    direction: "up"
  }, props, {
    ref: ref
  }));
});

var QuestionDialog = function QuestionDialog(_ref) {
  var _ref$id = _ref.id,
      id = _ref$id === void 0 ? '' : _ref$id,
      _ref$message = _ref.message,
      message = _ref$message === void 0 ? '' : _ref$message,
      _ref$title = _ref.title,
      title = _ref$title === void 0 ? '' : _ref$title,
      _ref$action = _ref.action,
      action = _ref$action === void 0 ? '' : _ref$action,
      _ref$handleAction = _ref.handleAction,
      handleAction = _ref$handleAction === void 0 ? function () {} : _ref$handleAction;
  var intl = useIntl();
  var theme = useTheme();

  var _useSimpleValues = useSimpleValues(),
      getValue = _useSimpleValues.getValue,
      setValue = _useSimpleValues.setValue;

  var handleClose = function handleClose() {
    setValue(id, false);
  };

  var fullScreen = useMediaQuery(theme.breakpoints.down('sm'));
  var isDialogOpen = getValue(id);
  return /*#__PURE__*/React.createElement(Dialog, {
    fullScreen: fullScreen,
    open: isDialogOpen,
    onClose: handleClose,
    TransitionComponent: Transition,
    "aria-labelledby": "alert-dialog-title",
    "aria-describedby": "alert-dialog-description"
  }, /*#__PURE__*/React.createElement(DialogTitle, {
    id: "alert-dialog-title"
  }, title), /*#__PURE__*/React.createElement(DialogContent, null, /*#__PURE__*/React.createElement(DialogContentText, {
    id: "alert-dialog-description"
  }, message)), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
    onClick: handleClose,
    color: "primary"
  }, intl.formatMessage({
    id: 'cancel',
    defaultMessage: 'Cancel'
  })), /*#__PURE__*/React.createElement(Button, {
    onClick: function onClick() {
      handleAction(handleClose);
    },
    color: "secondary"
  }, action)));
};

export default QuestionDialog;
